Each of hydra-zen's :ref:`config-creation functions <create-config>` has a `zen_config` 
parameter, which can be passed a dictionary to modify the function's value and type conversion behaviors. `hydra_zen.typing.ZenConfig` is a :py:class:`typing.TypedDict` 
that can be used as a convenience function to view and override these options.

The following documentation details the available zen-convert options and shows 
example use cases.

.. _zen-convert:

hydra\_zen.typing.ZenConvert
============================

.. currentmodule:: hydra_zen.typing

.. autoclass:: ZenConvert

